==> mx-viewer_23.9.tar.xz: BUILD/translations/mx-viewer_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DownloadWidget</name>
    <message>
        <location filename="../downloadwidget.ui" line="14"/>
        <source>Download Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="42"/>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="50"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="89"/>
        <source>%L1 B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="91"/>
        <source>%L1 KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="93"/>
        <source>%L1 MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="95"/>
        <source>%L1 GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="102"/>
        <source>%1sec.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="104"/>
        <source>%1min. %2sec.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="106"/>
        <source>%1h. %2m. %3s.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="126"/>
        <source>%p% - %1 of %2 at %3/s - %4 left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="133"/>
        <source>unknown size - %1 at %2/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="139"/>
        <source>completed - %1 at %2/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="144"/>
        <source>cancelled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="149"/>
        <source>interrupted: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="155"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="156"/>
        <source>Cancel downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="159"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="160"/>
        <source>Remove from list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Ctrl+R</source>
        <translation type="vanished">Ctrl+R</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">Hledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Select file to open</source>
        <translation>Vyberte soubor k otevření</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Hypertext Files (*.htm *.html);;All Files (*.*)</source>
        <translation>Hypertextové soubory  (*.htm *.html);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="vanished">Otevřít</translation>
    </message>
    <message>
        <source>Enter site or file URL:</source>
        <translation type="vanished">Zadejte stránku nebo URL souboru:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <source>Move up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <source>Move down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="130"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Rename bookmark:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>&amp;Clear history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>search in page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Add bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Keyboard Shortcuts</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Ctrl-F, or F3</source>
        <translation>Ctrl-F, nebo F3</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Find</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Shift-F3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Ctrl-R, or F5</source>
        <translation>Ctrl-R, nebo F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reload</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Find previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Ctrl-O</source>
        <translation>Ctrl-O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>Stop loading/clear Find field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>Alt→, Alt←</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Press [F11] to exit full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;New tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;Full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>H&amp;istory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>&amp;Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>&amp;Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Bookmark current address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>&amp;Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>About MX Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>This is a VERY basic browser based on Qt WebEngine.

The main purpose is to provide a basic document viewer for MX documentation. It could be used for LIMITED internet browsing, but it&apos;s not recommended to be used for anything important or secure because it&apos;s not a fully featured browser and its security/privacy features were not tested.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

MX Viewer is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with MX Viewer.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="vanished">Otevřít URL</translation>
    </message>
    <message>
        <source>Ctrl-B</source>
        <translation type="vanished">Ctrl-B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Browse file to open</source>
        <translation>Vyhledat soubor k otevření</translation>
    </message>
    <message>
        <source>Esc - Stop loading/clear Find field</source>
        <translation type="vanished">Esc - Stop nebo vyčistit pole Hladat</translation>
    </message>
    <message>
        <source>Alt-LeftArrow, Alt-RightArrow</source>
        <translation type="vanished">Alt-ŠipkaVlevo, Alt-ŠipkaVpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Back/Forward</source>
        <translation>Zpět/Kupředu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>F1, or ?</source>
        <translation>F1, nebo ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Open this help dialog</source>
        <translation>Zobrazí tento dialog nápovědy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>This tool will display the URL content in a window, window title is optional.</source>
        <translation type="vanished">Tento nástroj zobrazí obsah URL v okně, název okna je volitelný.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <source>Disable JavaScript</source>
        <translation>Vypnout JavaScript</translation>
    </message>
    <message>
        <source>Disable workaround for broken sites</source>
        <translation type="vanished">Vypnout řešení chyb pro poškozené stránky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="108"/>
        <source>Enable spatial navigation with keyboard</source>
        <translation>Povolit pohyb klávesnicí</translation>
    </message>
    <message>
        <source>Enable 3rd party cookies</source>
        <translation type="vanished">Povolit cookies třetích stran</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>This tool will display the URL content in a window, window title is optional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <source>Start program in full-screen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>Disable load images automatically from websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="102"/>
        <source>Drop program&apos;s rights to &apos;nobody&apos;. By default, if run as root, the rights are dropped to normal user. This option might provide additional protection, but the program would not be able to write its cache and cookies to the user directory, so it might break some functionality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>URL of the page you want to load</source>
        <translation>URL stránka, kterou chcete načíst</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>Window title for the viewer</source>
        <translation>Název okna pro prohlížeč</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="72"/>
        <source>New Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-viewer_25.7.tar.xz: BUILD/translations/mx-viewer_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DownloadWidget</name>
    <message>
        <location filename="../downloadwidget.ui" line="14"/>
        <source>Download Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="42"/>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="50"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="89"/>
        <source>%L1 B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="91"/>
        <source>%L1 KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="93"/>
        <source>%L1 MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="95"/>
        <source>%L1 GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="102"/>
        <source>%1sec.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="104"/>
        <source>%1min. %2sec.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="106"/>
        <source>%1h. %2m. %3s.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="126"/>
        <source>%p% - %1 of %2 at %3/s - %4 left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="128"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="133"/>
        <source>unknown size - %1 at %2/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="139"/>
        <source>completed - %1 at %2/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="144"/>
        <source>cancelled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="149"/>
        <source>interrupted: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="155"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="156"/>
        <source>Cancel downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="159"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../downloadwidget.cpp" line="160"/>
        <source>Remove from list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Ctrl+R</source>
        <translation type="vanished">Ctrl+R</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">Hledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Select file to open</source>
        <translation>Vyberte soubor k otevření</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Hypertext Files (*.htm *.html);;All Files (*.*)</source>
        <translation>Hypertextové soubory  (*.htm *.html);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="vanished">Otevřít</translation>
    </message>
    <message>
        <source>Enter site or file URL:</source>
        <translation type="vanished">Zadejte stránku nebo URL souboru:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>Full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>Move up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <source>Move down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Rename bookmark:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>&amp;Clear history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>search in page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Add bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Keyboard Shortcuts</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Ctrl-F, or F3</source>
        <translation>Ctrl-F, nebo F3</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Find</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Shift-F3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Ctrl-R, or F5</source>
        <translation>Ctrl-R, nebo F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Reload</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Find previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Ctrl-O</source>
        <translation>Ctrl-O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Stop loading/clear Find field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Alt→, Alt←</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Press [F11] to exit full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>&amp;New tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>H&amp;istory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>&amp;Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>&amp;Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Bookmark current address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>&amp;Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>About MX Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>This is a VERY basic browser based on Qt WebEngine.

The main purpose is to provide a basic document viewer for MX documentation. It could be used for LIMITED internet browsing, but it&apos;s not recommended to be used for anything important or secure because it&apos;s not a fully featured browser and its security/privacy features were not tested.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

MX Viewer is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with MX Viewer.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="vanished">Otevřít URL</translation>
    </message>
    <message>
        <source>Ctrl-B</source>
        <translation type="vanished">Ctrl-B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Browse file to open</source>
        <translation>Vyhledat soubor k otevření</translation>
    </message>
    <message>
        <source>Esc - Stop loading/clear Find field</source>
        <translation type="vanished">Esc - Stop nebo vyčistit pole Hladat</translation>
    </message>
    <message>
        <source>Alt-LeftArrow, Alt-RightArrow</source>
        <translation type="vanished">Alt-ŠipkaVlevo, Alt-ŠipkaVpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Back/Forward</source>
        <translation>Zpět/Kupředu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>F1, or ?</source>
        <translation>F1, nebo ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Open this help dialog</source>
        <translation>Zobrazí tento dialog nápovědy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>This tool will display the URL content in a window, window title is optional.</source>
        <translation type="vanished">Tento nástroj zobrazí obsah URL v okně, název okna je volitelný.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>Disable JavaScript</source>
        <translation>Vypnout JavaScript</translation>
    </message>
    <message>
        <source>Disable workaround for broken sites</source>
        <translation type="vanished">Vypnout řešení chyb pro poškozené stránky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>Enable spatial navigation with keyboard</source>
        <translation>Povolit pohyb klávesnicí</translation>
    </message>
    <message>
        <source>Enable 3rd party cookies</source>
        <translation type="vanished">Povolit cookies třetích stran</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>This tool will display the URL content in a window, window title is optional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <source>Start program in full-screen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <source>Disable load images automatically from websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Drop program&apos;s rights to &apos;nobody&apos;. By default, if run as root, the rights are dropped to normal user. This option might provide additional protection, but the program would not be able to write its cache and cookies to the user directory, so it might break some functionality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>URL of the page you want to load</source>
        <translation>URL stránka, kterou chcete načíst</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>Window title for the viewer</source>
        <translation>Název okna pro prohlížeč</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="80"/>
        <source>New Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
